local coveredBridge = ...

function registerBridge(_nameFbxFile, _option)
-- Register IDs for all prefab nodes referenced here
coveredBridge:registerAssetId("models/" .. _nameFbxFile .. ".fbx/Prefab/coveredBridge/CenterPart", CoveredBridgePrefix .. _option .. "_CENTER_PREFAB")
coveredBridge:registerAssetId("models/" .. _nameFbxFile .. ".fbx/Prefab/coveredBridge/RootPart", CoveredBridgePrefix .. _option .. "_CENTER_ROOT_PREFAB")
coveredBridge:registerAssetId("models/" .. _nameFbxFile .. ".fbx/Prefab/coveredBridge/TilingPart", CoveredBridgePrefix .. _option .. "_TILING_PREFAB")

-- Register bridge tiling (the pillar part that extends to the ground)
coveredBridge:register({
	DataType = "BUILDING_PART",
	Id = CoveredBridgePrefix .. _option .. "_TILING_PART",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = CoveredBridgePrefix .. _option .. "_TILING_PREFAB"
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "STONE", Quantity = _NoSandbox*1 }
		}
	},
})

function registerExtremity(_nameFbx, _extremity, _upperAttachType, _lowerAttachType)
    coveredBridge:registerAssetId("models/" .. _nameFbxFile .. ".fbx/Prefab/coveredBridge/" .. _nameFbx .. "SlopePart", CoveredBridgePrefix .. _option .. "_SLOPE_" .. _extremity .. "_PREFAB")
    coveredBridge:registerAssetId("models/" .. _nameFbxFile .. ".fbx/Prefab/coveredBridge/" .. _nameFbx .. "Part", CoveredBridgePrefix .. _option .. "_" .. _extremity .. "_PREFAB")

    -- Register bridge extremity part
    coveredBridge:register({
	DataType = "BUILDING_PART",
	Id = CoveredBridgePrefix .. _option .. "_" .. _extremity .. "_PART",
        Name = CoveredBridgePrefix .. _option .. "_" .. _extremity .. "_NAME",
        BuildingZone = _BridgeBuildingZone,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SLOPE",
		CoreObjectPrefab = CoveredBridgePrefix .. _option .. "_" .. _extremity .. "_PREFAB",
		SlopePartList = {
			CoveredBridgePrefix .. _option .. "_SLOPE_" .. _extremity .. "_PART"
		},
		CoreBasementPartList = {
			CoveredBridgePrefix .. _option .. "_TILING_PART"
		},
		UpperAttachType = _upperAttachType,
		LowerAttachType = _lowerAttachType
        },
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "STONE", Quantity = _NoSandbox*5 }
		}
	}
    })

    -- Register bridge extremity slope part
    coveredBridge:register({
	DataType = "BUILDING_PART",
	Id = CoveredBridgePrefix .. _option .. "_SLOPE_" .. _extremity .. "_PART",
        Name = CoveredBridgePrefix .. _option .. "_SLOPE_" .. _extremity .. "_NAME",
        BuildingZone = _BridgeBuildingZone,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BASEMENT",
		CoreObjectPrefab = CoveredBridgePrefix .. _option .. "_SLOPE_" .. _extremity .. "_PREFAB",
		FillerList = {
			CoveredBridgePrefix .. _option .. "_TILING_PART"
		}
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "STONE", Quantity = _NoSandbox*1 }
		}
	}
    })
end

registerExtremity("Start", "START", ATTACH_NODE_TYPE.RIGHT, ATTACH_NODE_TYPE.LEFT)
registerExtremity("End", "END", ATTACH_NODE_TYPE.LEFT, ATTACH_NODE_TYPE.RIGHT)

-- Register bridge center top part
coveredBridge:register({
	DataType = "BUILDING_PART",
	Id = CoveredBridgePrefix .. _option .. "_CENTER_TOP_PART",
        Name = CoveredBridgePrefix .. _option .. "_CENTER_TOP_NAME",
        BuildingZone = _BridgeBuildingZone,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = CoveredBridgePrefix .. _option .. "_CENTER_PREFAB"
	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "STONE", Quantity = _NoSandbox*5 },
			{ Resource = "PLANK", Quantity = _NoSandbox*1 }
		}
	}
})

-- Register the center root part (the scalable part that places multiple center top parts)
coveredBridge:register({
	DataType = "BUILDING_PART",
	Id = CoveredBridgePrefix .. _option .. "_CENTER_CORE_PART",
        Name = CoveredBridgePrefix .. _option .. "_CENTER_CORE_NAME",
        BuildingZone = _BridgeBuildingZone,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER",
		CoreObjectPrefab = CoveredBridgePrefix .. _option .. "_CENTER_ROOT_PREFAB",
		EndPart = CoveredBridgePrefix .. _option .. "_CENTER_TOP_PART",
		FillerList = {
			CoveredBridgePrefix .. _option .. "_TILING_PART"
		}	},
	Cost = {
		DataType = "BUILDING_PART_COST",
		RessourcesNeeded = {
			{ Resource = "STONE", Quantity = _NoSandbox*2 }
		}
	}
})

-- Register the core part (the part with the bridge mover)
coveredBridge:register({
	DataType = "BUILDING_PART",
	Id = CoveredBridgePrefix .. _option .. "_CORE_PART",
	Name = CoveredBridgePrefix .. _option .. "_CORE_NAME",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_BRIDGE",
		StartPart = CoveredBridgePrefix .. _option .. "_START_PART",
		EndPart = CoveredBridgePrefix .. _option .. "_END_PART",
		FillerList = {
			CoveredBridgePrefix .. _option .. "_CENTER_CORE_PART"
		},
		MinimumScale = 1,
                MinimumHeightAboveGround = 0
	},
	AssetBuildingFunction = CoveredBridgePrefix .. _option .. "_FUNCTION"
})
coveredBridge:register({
		DataType = "BUILDING_FUNCTION_BRIDGE",
                Id = CoveredBridgePrefix .. _option .. "_FUNCTION"
})

-- Configure all BRIDGE colliders

coveredBridge:configurePrefabFlagList("models/" .. _nameFbxFile .. ".fbx/Prefab/coveredBridge/CenterPart", { "BRIDGE" })
coveredBridge:configurePrefabFlagList("models/" .. _nameFbxFile .. ".fbx/Prefab/coveredBridge/StartPart", { "BRIDGE" })
coveredBridge:configurePrefabFlagList("models/" .. _nameFbxFile .. ".fbx/Prefab/coveredBridge/EndPart", { "BRIDGE" })
coveredBridge:configurePrefabFlagList("models/" .. _nameFbxFile .. ".fbx/Prefab/coveredBridge/StartSlopePart", { "BRIDGE" })
coveredBridge:configurePrefabFlagList("models/" .. _nameFbxFile .. ".fbx/Prefab/coveredBridge/EndSlopePart", { "BRIDGE" })
coveredBridge:configurePrefabFlagList("models/coveredBridgeGate.fbx/Prefab/coveredBridge/Gate/step_3_TopPart", { "PLATFORM" })
end

registerBridge("coveredBridge", "")
registerBridge("coveredBridgeLarge", "_LARGE")

-- Register IDs for all prefab nodes referenced here
coveredBridge:registerAssetId("models/coveredBridgeDecoration.fbx/Prefab/coveredBridge/CenterCoveragePart", CoveredBridgePrefix .. "_CENTER_COVERAGE_PREFAB")
coveredBridge:registerAssetId("models/coveredBridgeDecoration.fbx/Prefab/coveredBridge/StartEndCoveragePart", CoveredBridgePrefix .. "_START_END_COVERAGE_PREFAB")
coveredBridge:registerAssetId("models/coveredBridgeGate.fbx/Prefab/coveredBridge/Gate/step_0_RootPart", CoveredBridgePrefix .. "_GATE_ROOT_PREFAB")
coveredBridge:registerAssetId("models/coveredBridgeGate.fbx/Prefab/coveredBridge/Gate/step_3_TopPart", CoveredBridgePrefix .. "_GATE_TOP_PREFAB")
coveredBridge:registerAssetId("models/coveredBridgeGate.fbx/Prefab/coveredBridge/Gate/step_2_Tiling2Part", CoveredBridgePrefix .. "_GATE_TILING2_PREFAB")
coveredBridge:registerAssetId("models/coveredBridgeGate.fbx/Prefab/coveredBridge/Gate/step_1_Tiling3Part", CoveredBridgePrefix .. "_GATE_TILING3_PREFAB")

-- Create default building part registering function 
function registerDefaultBuildingPart(_nodePrefix)
	coveredBridge:register({
		DataType = "BUILDING_PART",
		Id = _nodePrefix .. "_PART",
                Name = _nodePrefix .. "_NAME",
		ConstructorData = {
                    DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
                    CoreObjectPrefab = _nodePrefix .. "_PREFAB"
                },
	        Cost = {
		    UpkeepCost = {
			{ Resource = "GOLD", Quantity = _NoSandbox*1 }
		    },
		    RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = _NoSandbox*2 }
		    }
	        },
	        EstateSplendor = {
		    { Estate = "KINGDOM", Quantity = 0.1 }
	    }
	})
end

local defaultNodePrefixList = {
	CoveredBridgePrefix .. "_GATE_TILING2",
	CoveredBridgePrefix .. "_GATE_TILING3"}

-- Register simple building part assets
for i, nodePrefix in ipairs(defaultNodePrefixList) do
	registerDefaultBuildingPart(nodePrefix)
end

-- Register the stone watch tower (gate) part
coveredBridge:register({
	DataType = "BUILDING_PART",
	Id = CoveredBridgePrefix .. "_GATE_ROOT_PART",
	Name = CoveredBridgePrefix .. "_GATE_ROOT_NAME",
	Description = CoveredBridgePrefix .. "_GATE_ROOT_DESC",
	Category = "CORE",
        BuildingZone = _GateBuildingZone,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = CoveredBridgePrefix .. "_GATE_ROOT_PREFAB",
		EndPart = CoveredBridgePrefix .. "_GATE_TOP_PART",
		FillerList = {
			CoveredBridgePrefix .. "_GATE_TILING2_PART"
                },
		BasementFillerList = {
			CoveredBridgePrefix .. "_GATE_TILING3_PART"
         	},
		MinimumScale = 0,
		IsVertical = true,
                MiniatureConfig = {
                        DataType = "BUILDING_MINIATURE_CONFIG",
                        ClipUnderGround = false
                }
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = _NoSandbox*0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = _NoSandbox*2 }
		}
	},
	EstateSplendor = {
		{ Estate = "KINGDOM", Quantity = 1 }
	},
--	AssetBuildingFunction = CoveredBridgePrefix .. "_GATE_FUNCTION"
  	AssetBuildingFunction = CoveredBridgePrefix .. "_ASSIGNABLE_SOLDIER_FUNCTION" 
})
coveredBridge:register({
		DataType = "BUILDING_FUNCTION_ASSIGNABLE",
                Id = CoveredBridgePrefix .. "_ASSIGNABLE_SOLDIER_FUNCTION",
                AuthorizedFunctionList = CoveredBridgePrefix .. "_SOLDIER_FUNCTION_LIST"
})
coveredBridge:register({
		DataType = "BUILDING_FUNCTION_LIST",
                Id = CoveredBridgePrefix .. "_SOLDIER_FUNCTION_LIST",
                    AssetFunctionList = {
--                        CoveredBridgePrefix .. "_GATE_FUNCTION",
                        CoveredBridgePrefix .. "_GATE_FUNCTION2"
                }
})

-- kept for compatibility
coveredBridge:register({
		DataType = "BUILDING_FUNCTION_WORKPLACE",
                Id = CoveredBridgePrefix .. "_GATE_FUNCTION",
		WorkerCapacity = 2,
                RelatedJob = { Job = "SOLDIER", Behavior = "BEHAVIOR_WORK" }
})
coveredBridge:register({
        DataType = "BUILDING_FUNCTION_TRAINING_GROUND",
        Id = CoveredBridgePrefix .. "_GATE_FUNCTION2",
        Name = CoveredBridgePrefix .. "_GATE_FUNCTION2_NAME",
        WorkerCapacity = 1,
        RelatedJob = { Job = "SOLDIER", Behavior = CoveredBridgePrefix .. "_BEHAVIOR_TREE" },
        TrainingBehaviorList = { CoveredBridgePrefix .. "_BEHAVIOR_TREE" },
        VillagerProfile = "PROFILE_SOLDIER"
})

if _flagSecurity then
    coveredBridge:register({
        DataType = "BUILDING_FUNCTION_WORKPLACE",
        Id = CoveredBridgePrefix .. "_BUILDING_FUNCTION_SECURITY_GUARD_TOWER2",
        Name = "BUILDING_FUNCTION_SECURITY_GUARD_TOWER2_NAME",
        WorkerCapacity = 1,
        RelatedJob = { 
            Job = "JOB_SECURITY_GUARD_TOWER", 
            Behavior = CoveredBridgePrefix .. "_BEHAVIOR_TREE"
        },
        InputInventoryCapacity = {
	    },
        ResourceListNeeded = {
	    },
	ResourceProduced = {
            { Resource = "RESOURCE_REPORT", Quantity = 2 },
        }
    })
    coveredBridge:override({
		DataType = "BUILDING_FUNCTION_LIST",
                Id = CoveredBridgePrefix .. "_SOLDIER_FUNCTION_LIST",
                AssetFunctionList = {
                        Action = "APPEND",
                        CoveredBridgePrefix .. "_BUILDING_FUNCTION_SECURITY_GUARD_TOWER2"
                }
    })
end

coveredBridge:register({
	DataType = "BUILDING_PART",
	Id = CoveredBridgePrefix .. "_GATE_TOP_PART",
	ConstructorData = {
                   DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
                   CoreObjectPrefab = CoveredBridgePrefix .. "_GATE_TOP_PREFAB"
        },
        Cost = {
	    UpkeepCost = {
		{ Resource = "GOLD", Quantity = _NoSandbox*1 }
	    },
	    RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
		{ Resource = "STONE", Quantity = _NoSandbox*2 }
	    }
        },
        EstateSplendor = {
	    { Estate = "KINGDOM", Quantity = 0.1 }
        }
})

function registerAssignableFunction(_assetPrefix, _assetId)
    coveredBridge:register({
		DataType = "BUILDING_FUNCTION_LIST",
                Id = _assetPrefix .. "_" .. _assetId .. "_FUNCTION_LIST",
                AssetFunctionList = {
                        CoveredBridgePrefix .. "_TAILOR_FUNCTION",
                        "BUILDING_FUNCTION_FOOD_MARKET",
                        "BUILDING_FUNCTION_GOODS_MARKET",
                        "BUILDING_FUNCTION_LUXURY_MARKET",
                        registerFunctionHouse(_assetPrefix, _assetId, "1"),
                        registerFunctionHouse(_assetPrefix, _assetId, "2")
                }
    })
    coveredBridge:register({
		DataType = "BUILDING_FUNCTION_ASSIGNABLE",
                Id = _assetPrefix .. "_" .. _assetId .. "_ASSIGNABLE_FUNCTION",
                AuthorizedFunctionList = _assetPrefix .. "_" .. _assetId .. "_FUNCTION_LIST"
    })
    return _assetPrefix .. "_" .. _assetId .. "_ASSIGNABLE_FUNCTION"
end
coveredBridge:register({
		DataType = "BUILDING_FUNCTION_ASSIGNABLE",
                Id = CoveredBridgePrefix .. "_ASSIGNABLE_FUNCTION",
                AuthorizedFunctionList = CoveredBridgePrefix .. "_FUNCTION_LIST"
})

coveredBridge:register({
		DataType = "BUILDING_FUNCTION_LIST",
                Id = CoveredBridgePrefix .. "_FUNCTION_LIST",
                    AssetFunctionList = {
                        CoveredBridgePrefix .. "_TAILOR_FUNCTION",
                        "BUILDING_FUNCTION_FOOD_MARKET",
                        "BUILDING_FUNCTION_GOODS_MARKET",
                        "BUILDING_FUNCTION_LUXURY_MARKET"
                }
})

coveredBridge:register({
		DataType = "BUILDING_FUNCTION_MARKET",
                Id = CoveredBridgePrefix .. "_TAILOR_FUNCTION",
                Name = CoveredBridgePrefix .. "_TAILOR_FUNCTION_NAME",
                TypeList = { "GOODS" },
                IsOverrideCapacity = true,
                CapacityPerSlot = 20,
		WorkerCapacity = 1,
                RelatedJob = { Job = "TAILOR", Behavior = "BEHAVIOR_WORK" },
                InputInventoryCapacity = {
			{ Resource = "WOOLEN_CLOTH", Quantity = 20 }
                },
                ResourceListNeeded = {
			{ Resource = "WOOLEN_CLOTH", Quantity = 1 }
                },
                ResourceProduced = {
			{ Resource = "CLOTHES", Quantity = 1 }
                }
})

coveredBridge:dofile("scripts/compCoveredBridge.lua")

-- Register the house decoration part
function registerHousePart(_nameFbx, _namePart, _nameAsset)
    coveredBridge:registerAssetId("models/" .. _nameFbx .. ".fbx/Prefab/coveredBridge/" .. _namePart .. "Part", CoveredBridgePrefix .. "_" .. _nameAsset .. "_PREFAB")
    coveredBridge:register({
	DataType = "BUILDING_PART",
	Id = CoveredBridgePrefix .. "_" .. _nameAsset .. "_PART",
	Name = CoveredBridgePrefix .. "_" .. _nameAsset .. "_NAME",
	Description = CoveredBridgePrefix .. "_" .. _nameAsset .. "_DESC",
	Category = "DECORATION",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = CoveredBridgePrefix .. "_" .. _nameAsset .. "_PREFAB",
                MiniatureConfig = {
                        DataType = "BUILDING_MINIATURE_CONFIG",
                        ClipUnderGround = false
                }
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = _NoSandbox*0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "PLANK", Quantity = _NoSandbox*5 }
		}
	},
        VillagerCapacity = 2,
  	AssetBuildingFunction = registerAssignableFunction(CoveredBridgePrefix, _nameAsset) 
    })

    coveredBridge:registerPrefabComponent("models/" .. _nameFbx .. ".fbx/Prefab/coveredBridge/" .. _namePart .. "Part", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MINOR" -- Snaps the decoration only on minor attach nodes
    })

    coveredBridge:configurePrefabFlagList("models/" .. _nameFbx .. ".fbx/Prefab/coveredBridge/" .. _namePart .. "Part", { "BRIDGE" })

    coveredBridge:registerPrefabComponent("models/" .. _nameFbx .. ".fbx/Prefab/coveredBridge/" .. _namePart .. "Part/PATH_A_0", {
	DataType = CoveredBridgePrefix .. "_PATH_COMP",
	Enabled = true,
        Direction = 1
    })
    coveredBridge:registerPrefabComponent("models/" .. _nameFbx .. ".fbx/Prefab/coveredBridge/" .. _namePart .. "Part/PATH_B_0", {
	DataType = CoveredBridgePrefix .. "_PATH_COMP",
	Enabled = true,
        Direction = -1
    })
end

registerHousePart("coveredBridgeDecoration", "House", "HOUSE")
registerHousePart("coveredBridgeDecoration", "Food", "RED")
registerHousePart("coveredBridgeDecoration", "Goods", "GREEN_A")
registerHousePart("coveredBridgeDecoration", "Luxury", "BLUE")
registerHousePart("coveredBridgeDecoration", "Tailor", "GREEN_B")
registerHousePart("coveredBridgeAddition", "Hat", "RED_WINE")
registerHousePart("coveredBridgeAddition", "Knife", "CARBON")
registerHousePart("coveredBridgeLargeHouse", "HouseTower1", "HOUSE_TOWER1")
registerHousePart("coveredBridgeLargeHouse", "HouseMiddle1", "HOUSE_MIDDLE1")
registerHousePart("coveredBridgeLargeHouse", "HouseMiddle2", "HOUSE_MIDDLE2")

-- Register the center coverage decoration part
coveredBridge:register({
	DataType = "BUILDING_PART",
	Id = CoveredBridgePrefix .. "_CENTER_COVERAGE_PART",
	Name = CoveredBridgePrefix .. "_CENTER_COVERAGE_NAME",
	Description = CoveredBridgePrefix .. "_CENTER_COVERAGE_DESC",
	Category = "DECORATION",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = CoveredBridgePrefix .. "_CENTER_COVERAGE_PREFAB",
                MiniatureConfig = {
                        DataType = "BUILDING_MINIATURE_CONFIG",
                        ClipUnderGround = false
                }
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = _NoSandbox*0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "PLANK", Quantity = _NoSandbox*5 }
		}
	}
})

-- Register the start or end coverage decoration part
coveredBridge:register({
	DataType = "BUILDING_PART",
	Id = CoveredBridgePrefix .. "_START_END_COVERAGE_PART",
	Name = CoveredBridgePrefix .. "_START_END_COVERAGE_NAME",
	Description = CoveredBridgePrefix .. "_START_END_COVERAGE_DESC",
	Category = "DECORATION",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = CoveredBridgePrefix .. "_START_END_COVERAGE_PREFAB",
                MiniatureConfig = {
                        DataType = "BUILDING_MINIATURE_CONFIG",
                        ClipUnderGround = false
                }
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = _NoSandbox*0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "PLANK", Quantity = _NoSandbox*2 }
		}
	}
})

--------------------------------------------------------------------------

-- Override building part components properties (generated by the building asset processor) to add building zones

coveredBridge:registerPrefabComponent("models/coveredBridgeGate.fbx/Prefab/coveredBridge/Gate/step_0_RootPart", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MINOR" -- Snaps the decoration only on minor attach nodes
})

coveredBridge:registerPrefabComponent("models/coveredBridgeDecoration.fbx/Prefab/coveredBridge/CenterCoveragePart", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MINOR" -- Snaps the decoration only on minor attach nodes
})

coveredBridge:registerPrefabComponent("models/coveredBridgeDecoration.fbx/Prefab/coveredBridge/StartEndCoveragePart", {
	DataType = "COMP_BUILDING_PART",
	BuildingPartType = "MINOR" -- Snaps the decoration only on minor attach nodes
})

